@@ -26,9 +26,10 @@ class ResultReceiver(object):
         self.qos = qos or 10
         self.queue_expires = queue_expires or 28800
         self.inactivity_timeout = inactivity_timeout or 1800
+        LOGGER.info(f'[采集结果]结果监听器已启动 rabbit={self.rabbit_uri}')
 
     async def consume(self, tenant_code: str, batch_id: str, exchange_name: str, routing_name: str, queue_name: str):
-        LOGGER.info(f'[采集结果]开始接收 batch_id={batch_id}')
+        LOGGER.info(f'[采集结果]开始接收... batch_id={batch_id}')
 
         connection = await aio_pika.connect_robust(self.rabbit_uri)
         channel = await connection.channel()
@@ -59,51 +60,51 @@ class ResultReceiver(object):
             await connection.close()
 
         LOGGER.info(f'[采集结果]接收完成 batch_id={batch_id}')
-
-
-@singleton
-class ZipNotifyReceiver(object):
-    """
-    【单例】异步打包通知接收
-    1、由爬虫停止信号接收到为触发点，由打包请求操作发起
-    2、通道常驻，不随批次删除
-    3、通道按app_code区分
-    """
-
-    def __init__(self, processor: AbstractMessageProcess, rabbit_uri: str, qos: int = None):
-        self.processor = processor
-        self.rabbit_uri = rabbit_uri
-        self.qos = qos or 10
-
-    async def consume(self, exchange_name: str, routing_name: str, queue_name: str):
-        LOGGER.info(f'[打包通知]开始接收')
-
-        connection = await aio_pika.connect_robust(self.rabbit_uri)
-        channel = await connection.channel()
-        # 服务质量保证，在非自动确认情况下，一定数目的消息没有确认，不进行消费新的消息
-        await channel.set_qos(self.qos)
-        queue = await channel.declare_queue(
-            name=queue_name,
-            auto_delete=False,
-        )
-        await channel.declare_exchange(name=exchange_name)
-        await queue.bind(exchange=exchange_name, routing_key=routing_name)
-        LOGGER.info(f'[打包通知]队列信息 queue={queue_name}, exchange={exchange_name}, routing={routing_name}')
-
-        try:
-            async with queue.iterator() as queue_iter:
-                async for message in queue_iter:
-                    self.processor.process_message(message=message)
-                    await message.ack()
-        except Exception:
-            LOGGER.error(f'[打包通知]发生异常 {traceback.format_exc()}')
-        finally:
-            await queue.unbind(exchange_name, routing_name)
-            await queue.delete()
-            await channel.close()
-            await connection.close()
-
-        LOGGER.info(f'[打包通知]停止接收')
+#
+#
+# @singleton
+# class ZipNotifyReceiver(object):
+#     """
+#     【单例】异步打包通知接收
+#     1、由爬虫停止信号接收到为触发点，由打包请求操作发起
+#     2、通道常驻，不随批次删除
+#     3、通道按app_code区分
+#     """
+#
+#     def __init__(self, processor: AbstractMessageProcess, rabbit_uri: str, qos: int = None):
+#         self.processor = processor
+#         self.rabbit_uri = rabbit_uri
+#         self.qos = qos or 10
+#
+#     async def consume(self, exchange_name: str, routing_name: str, queue_name: str):
+#         LOGGER.info(f'[打包通知]开始接收')
+#
+#         connection = await aio_pika.connect_robust(self.rabbit_uri)
+#         channel = await connection.channel()
+#         # 服务质量保证，在非自动确认情况下，一定数目的消息没有确认，不进行消费新的消息
+#         await channel.set_qos(self.qos)
+#         queue = await channel.declare_queue(
+#             name=queue_name,
+#             auto_delete=False,
+#         )
+#         await channel.declare_exchange(name=exchange_name)
+#         await queue.bind(exchange=exchange_name, routing_key=routing_name)
+#         LOGGER.info(f'[打包通知]队列信息 queue={queue_name}, exchange={exchange_name}, routing={routing_name}')
+#
+#         try:
+#             async with queue.iterator() as queue_iter:
+#                 async for message in queue_iter:
+#                     self.processor.process_message(message=message)
+#                     await message.ack()
+#         except Exception:
+#             LOGGER.error(f'[打包通知]发生异常 {traceback.format_exc()}')
+#         finally:
+#             await queue.unbind(exchange_name, routing_name)
+#             await queue.delete()
+#             await channel.close()
+#             await connection.close()
+#
+#         LOGGER.info(f'[打包通知]停止接收')
 
 
 @singleton
